clear all;close all;clc;tic;
bSave = 0;
vtEbNodB = [0:2:35]; % valores de Eb/No a simular
vtEbNo = 10.^(vtEbNodB/10); % Eb/No em escala linear
vtNumAntenasRx = [2 4 8]; % nmero de antenas no receptor
iMaxAnt = max(vtNumAntenasRx); % tamanho do vetor de antenas
vtBspkSimb = [ -1 1 ]; % smbolos da modulao BPSK antipodal
Eb = sum(vtBspkSimb*vtBspkSimb') / length(vtBspkSimb); % energia de bit
vtNo = Eb./vtEbNo; % PSD do rudo AWGN
iNbits = 1e6; % nmero de bits a simular
for iSNR = 1 : length(vtEbNodB) % loop no vetor de Eb/No
    disp(['Simulando Eb/No = ' num2str(vtEbNodB(iSNR)) ' dB...']);
    % transmissor
    vtBits = randi([0,1], 1, iNbits); % fonte de bits aleatrios
    vtSimb = vtBspkSimb( vtBits + 1 ); % bits para smbolos antipodais
    mtSimb = repmat(vtSimb,iMaxAnt,1); % smbolos de cada antena receptora
    % canal (AWGN e Rayleigh)
    mtCanalAWGN = sqrt(vtNo(iSNR)/2)*[randn(iMaxAnt,iNbits) + j*randn(iMaxAnt,iNbits)];
    mtRayleigh = 1/sqrt(2)*[randn(iMaxAnt,iNbits) + j*randn(iMaxAnt,iNbits)];
    vtSinalRecAWGN = vtSimb + mtCanalAWGN(1,:); % sinal recebido com rudo AWGN
    % sinal recebido com desvanecimento plano e rudo AWGN
    mtSinalRecRay = mtSimb.*mtRayleigh + mtCanalAWGN;
    % recepo AWGN e estimao da BER somente com AWGN
    vtBitsDecAWGN = real(vtSinalRecAWGN)>0;
    vtBERAWGN(iSNR) = length(find([vtBits+vtBitsDecAWGN]==1))/iNbits;
    % recepo Rayleigh e estimao da BER com AWGN e desvanecimento
    vtSinalEqual = mtSinalRecRay(1,:)./mtRayleigh(1,:); % equalizao
    vtBitsDecRay = real(vtSinalEqual)>0;
    vtBERRay(iSNR) = length(find([vtBits+vtBitsDecRay]==1))/iNbits;
    % recepo com diversidade MRC (AWGN e desvanecimento)
    mtAng = angle(mtRayleigh);
    mtAmp = abs(mtRayleigh);
    % decodificao baseada no vetor de antenas e em todos os bits de uma vez
    for iAnt = 1 : length(vtNumAntenasRx) 
        nAnt = vtNumAntenasRx(iAnt);
        vtSinalMRC = sum(mtAmp(1:nAnt,:).*mtSinalRecRay(1:nAnt,:).*exp(-j*mtAng(1:nAnt,:)))./sum(mtAmp(1:nAnt,:).^2);
        vtBitsDecMRC = real(vtSinalMRC)>0;
        mtBERMRC(iAnt,iSNR) = length(find([vtBits+vtBitsDecMRC]==1))/iNbits;
    end
    %clear vtBits, vtSimb, mtSimb, mtCanalAWGN, mtSinalRecRay, vtBitsDecAWGN;
end
% probabilidade de erro terica
vtPeAWGN = 0.5*erfc(sqrt(vtEbNo)); % Pe AWGN
vtPeRay = 0.5*(1-sqrt(vtEbNo./(vtEbNo+1))); % Pe Rayleigh
p = 1/2-1/2*(1+1./vtEbNo).^(-1/2); vtPeMRC = p.^2.*(1+2*(1-p)); % Pe MRC 2 antenas
save('simEnlace.mat','vtEbNodB','vtEbNo','vtPeRay','vtBERRay','vtPeMRC','mtBERMRC','vtPeAWGN','vtBERAWGN');                       

%% grfico 1: comparao AWGN, Rayleigh e Diversidade MRC e EGC (2 antenas)
%figure; set(gcf, 'Position', get(0,'Screensize'));
%semilogy(vtEbNodB, vtPeRay, 'linewidth',3, 'MarkerSize',12);hold all;
%semilogy(vtEbNodB, vtBERRay,'o', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, vtPeMRC,':', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, mtBERMRC(1,:),'^', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, vtPeAWGN,'--', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, vtBERAWGN,'s', 'linewidth',3, 'MarkerSize',12);
%set (gca, "Interpreter", "tex"); 
%set(gca,'fontsize',20,'FontWeight', 'bold');
%chLegend = ['Pe Rayleigh';'BER Rayleigh (simulado)'];
%chLegend = [ chLegend ;'Pe MRC 2 antenas';'BER MRC 2 antenas (simulado)'];
%chLegend = [ chLegend ;'Pe AWGN';'BER AWGN (simulado)'];
%legend(chLegend,'Location','northeast'); 
%xlabel('Eb/No'); 
%ylabel('BER');
%axis([min(vtEbNodB) max(vtEbNodB) 1e-5 1]); 
%grid on;
%%###############
%if ( bSave == 1)
%saveas (gcf, "fig_cap11_AWGN_Ray_MRC.png");
%print -color -depsc fig_cap11_AWGN_Ray_MRC.eps
%end
%%###############
%% grfico 2: comparao Diversidade MRC com nmero diferentes de antenas
%figure; set(gcf, 'Position', get(0,'Screensize'));
%semilogy(vtEbNodB, vtBERRay,'o-', 'linewidth',3, 'MarkerSize',12);hold all;
%semilogy(vtEbNodB, mtBERMRC(1,:),'s--', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, mtBERMRC(2,:),'d-.', 'linewidth',3, 'MarkerSize',12);
%semilogy(vtEbNodB, mtBERMRC(3,:),'*:', 'linewidth',3, 'MarkerSize',12);
%set (gca, "Interpreter", "tex"); 
%set(gca, 'fontsize',20,'FontWeight', 'bold'); grid on;
%chLegend = ['BER Rayleigh (1 antena)';'BER Rayleigh - MRC (2 antenas)'];
%chLegend = [chLegend ;'BER Rayleigh - MRC (4 antenas)';'BER Rayleigh - MRC (8 antenas)'];
%legend(chLegend,'Location','northeast'); xlabel('Eb/No'); ylabel('BER'); 
%disp(['Durao = ' num2str(toc/60) ' minutos...']);
%%###############
%if ( bSave == 1)
%saveas (gcf, "fig_cap11_MRC_varias_antenas.png");
%print -color -depsc  fig_cap11_MRC_varias_antenas.eps
%end
%%###############