function dTempoExp = fSimulador( sPar )
tic; % contagem do tempo do experimento
% centro das sete ERBs hexagonais
vtERBs = [0]; offset = pi/6;
for iBs = 2 : 7
    vtERBs = [vtERBs sPar.dR*sqrt(3)*exp(j*((iBs-2)*pi/3 + offset))];
end
iNERBs = length(vtERBs); % nmero de ERBs
vtSINRDSSSdB2Salvar = []; % vetor para armazenamento da SINR DSSS
vtSINRdB2Salvar = []; % vetor para armazenamento da SINR
vtPrdB2Salvar = []; % vetor para armazenamento da potncia recebida
% matriz da posio (complexa) de cada usurio para cada uma das 7 ERBS (posio relativa
% a ERB central). As linhas so indexadas pelos usurios e as colunas pelas ERBs.
mtSectorPos = zeros( sPar.dUsrPerErb, iNERBs );
% matriz de potncia recebida na ERB central de cada usurio das 7 ERBs. 
mtPrx2ERBCentralmW = zeros( sPar.dUsrPerErb, iNERBs );
for isim = 1: sPar.iRep % loop no nmero de interaes de Monte Carlo
    for iERB = 1 : iNERBs % criao dos usurios em cada ERB
        mtSectorPos( :, iERB ) = fPosUsrErb( sPar, vtERBs( iERB ) );
        % figura com o posicionamento dos usurios e ERBs (se configurado)
        if ( sPar.bPlotUsrs ) 
            fDesenhaErb( sPar.dR, vtERBs( iERB ) ); hold all;
            plot(mtSectorPos(:,iERB ),'*');plot(vtERBs,'bs','LineWidth',2);
            legend('Limite da ERB','Usurios','ERB'); 
        end
        % clculo da potncia recebida na ERB central de todos os usurios 
        vt2BSDist = abs( mtSectorPos( :, iERB ) - vtERBs(1) ); % distncia em m
        vtPldB = 129.4+35.2*log10(vt2BSDist/1e3); % perda de percurso em dB
        vtXsdB(:,iERB) = sPar.dSigma*randn(sPar.dUsrPerErb,1); % sombreamento em dB
        vtPrdBm = sPar.GadBi+vtXsdB(:,iERB)+sPar.dPtxdBm-vtPldB; % Prx em dBm
        vtPrmW = 10.^( vtPrdBm / 10); % potncia recebida (Prx) em mW
        mtPrx2ERBCentralmW( :, iERB ) = vtPrmW; % armazenamento de Prx em mW
    end
    % figura com o posicionamento dos usurios e ERBs (se configurado)
    if ( sPar.bPlotUsrs ), dTempoExp = toc; return; end 
    % clculo da SINR para sistemas DSSS
    vtPr = mtPrx2ERBCentralmW(:,1); % potncia recebida til em mW
    % interferncia intra-celular em mW
    vtIntraInter = sum(mtPrx2ERBCentralmW(:,1))- mtPrx2ERBCentralmW(:,1); 
    dInter = sum(sum(mtPrx2ERBCentralmW(:,2:7))); % interferncia inter-celular em mW
    vtSINRDSSS = sPar.Gp * vtPr ./ ( vtIntraInter + dInter + sPar.dPnmW ); % SINR DSSS
    % clculo da SINR para sistema sem DSSS
    % interferncia inter-celular, assumindo existncia um usurio co-canal em cada ERB
    vtInter = sum(mtPrx2ERBCentralmW(:,2:7),2); 
    vtSINR = vtPr ./ ( vtInter + sPar.dPnmW ); % SINR 
    % armazenamento das mtricas de sada
    vtSINRdB2Salvar = [ vtSINRdB2Salvar 10*log10(vtSINR).'];
    vtSINRDSSSdB2Salvar = [ vtSINRDSSSdB2Salvar 10*log10(vtSINRDSSS).'];
    vtPrdB2Salvar = [vtPrdB2Salvar 10*log10( vtPr ).'];
end
% nome do arquivo de armazenamento de resultados
chArq = ['ULSim_carga_' num2str(sPar.dUsrPerErb) '_raio_' num2str(sPar.dR) '_rep_' num2str(sPar.iRep) '.mat'];
[s,m,mi] = mkdir( sPar.chPastaSaida );
cd( sPar.chPastaSaida );
dTempoExp = toc;
save(chArq, 'vtSINRdB2Salvar', 'vtSINRDSSSdB2Salvar', 'vtPrdB2Salvar','dTempoExp');
cd('../')
disp(['Experimento salvo em ' chArq ' , tempo de execuo = ' num2str(dTempoExp) ' s.']);
